@@ -1,15 +1,12 @@
 from concurrent.futures import Future
 from functools import wraps
 from subprocess import Popen
-from typing import Callable, Union
-
-from ..util.type import T
+from typing import Callable, Union, Any
 
 
-def run_blocking(func: Callable[..., Union[Future, Popen]]) -> Callable[..., T]:
-
+def run_blocking(func: Callable[..., Union[Future, Popen]]) -> Callable[..., Any]:
     @wraps(func)
-    def wrapper(*args, **kwargs) -> T:
+    def wrapper(*args, **kwargs) -> Any:
         task = func(*args, **kwargs)
         if isinstance(task, Future):
             return task.result()
@@ -20,4 +17,3 @@ def run_blocking(func: Callable[..., Union[Future, Popen]]) -> Callable[..., T]:
             raise TypeError("run_blocking only works with Future or Popen")
 
     return wrapper
-
