@@ -2,8 +2,9 @@ from .color import Colors, ContinuousColors
 from . import matplotlib
 from .multi_plots import MultiPlots
 from . import watcher
+from . import tensorboard
 
-__all__ = ["Colors", "ContinuousColors", "MultiPlots", "matplotlib", "watcher"]
+__all__ = ["Colors", "ContinuousColors", "MultiPlots", "matplotlib", "watcher", "tensorboard"]
 
 try:
     from . import seaborn
